@@ -19,7 +19,7 @@
 
   Configuration module 
 
-  $Id: config.c,v 1.16 2004/04/06 08:49:34 bengen Exp $
+  $Id: config.c,v 1.17 2005/02/03 09:25:52 bengen Exp $
  */
 
 #include <syslog.h>
@@ -122,70 +122,80 @@ struct config *read_config(char *fname)
 		case '%':
 		  switch(*++value)
 		    {
+		    case 'x':
+		      cfg->output|=(1<<OUT_SINCE);
+		      strcpy(tmpc,"%1$u");
+		      tmpc+=4;
+		      break;
 		    case 't':
 		      cfg->output|=(1<<OUT_TIMESTAMP);
-		      strcpy(tmpc,"%1$u");
+		      strcpy(tmpc,"%2$u");
 		      tmpc+=4;
 		      break;
 		    case 'p':
 		      cfg->output|=(1<<OUT_PROTO);
-		      strcpy(tmpc,"%2$u");
+		      strcpy(tmpc,"%3$u");
 		      tmpc+=4;
 		      break;
 		    case 's':
 		      cfg->output|=(1<<OUT_SRC);
-		      strcpy(tmpc,"%3$s");
+		      strcpy(tmpc,"%4$s");
 		      tmpc+=4;
 		      break;
 		    case 'S':
 		      cfg->output|=(1<<OUT_SRCPORT);
-		      strcpy(tmpc,"%4$hu");
+		      strcpy(tmpc,"%5$hu");
 		      tmpc+=5;
 		      break;
 		    case 'd':
 		      cfg->output|=(1<<OUT_DST);
-		      strcpy(tmpc,"%5$s");
+		      strcpy(tmpc,"%6$s");
 		      tmpc+=4;
 		      break;
 		    case 'D':
 		      cfg->output|=(1<<OUT_DSTPORT);
-		      strcpy(tmpc,"%6$hu");
+		      strcpy(tmpc,"%7$hu");
 		      tmpc+=5;
 		      break;
 		    case 'P':
 		      cfg->output|=(1<<OUT_PACKETS);
-		      strcpy(tmpc,"%7$u");
+		      strcpy(tmpc,"%8$u");
 		      tmpc+=4;
 		      break;
 		    case 'b':
 		      cfg->output|=(1<<OUT_BYTES);
-		      strcpy(tmpc,"%8$lu");
+		      strcpy(tmpc,"%9$lu");
 		      tmpc+=5;
 		      break;
 		    case 'i':
 		      cfg->output|=(1<<OUT_INDEV);
-		      strcpy(tmpc,"%9$s");
-		      tmpc+=4;
+		      strcpy(tmpc,"%10$s");
+		      tmpc+=5;
 		      break;
 		    case 'o':
 		      cfg->output|=(1<<OUT_OUTDEV);
-		      strcpy(tmpc,"%10$s");
+		      strcpy(tmpc,"%11$s");
 		      tmpc+=5;
 		      break;
 		    case 'f':
 		      cfg->output|=(1<<OUT_PREFIX);
-		      strcpy(tmpc,"%11$s");
+		      strcpy(tmpc,"%12$s");
 		      tmpc+=5;
 		      break;
 		    case 'u':
 		      cfg->output|=(1<<OUT_LOCAL_UID);
-		      strcpy(tmpc,"%12$d");
+		      strcpy(tmpc,"%13$d");
 		      syslog(LOG_DEBUG,"config: includeing LOCAL_UID");
 		      tmpc+=5;
 		      break;
+		    case 'X':
+		      cfg->output|=(1<<OUT_TIMESTRING_SINCE);
+		      strcpy(tmpc,"%14$s");
+		      tmpc+=5;
+		      break;
 		    case 'Z':
 		      cfg->output|=(1<<OUT_TIMESTRING);
-		      strcpy(tmpc,"%13$s");
+		      strcpy(tmpc,"%15$s");
 		      tmpc+=5;
 		      break;
 		    case 'h':
@@ -194,7 +204,7 @@ struct config *read_config(char *fname)
 		      break;
 		    case 'm':
 		      cfg->output|=(1<<OUT_MAC);
-		      strcpy(tmpc,"%14$s");
+		      strcpy(tmpc,"%16$s");
 		      tmpc+=5;
 		      break;
 		    case '%': strcpy(tmpc,"%%"); tmpc+=2; break;
