@@ -3,7 +3,7 @@
 
   (C) 2002 Hilko Bengen
 
-  $Id: config.h,v 1.12 2003/08/26 13:34:29 bengen Exp $
+  $Id: config.h,v 1.13 2004/04/06 08:49:35 bengen Exp $
 */
 
 struct config
@@ -21,6 +21,8 @@ struct config
   int output, debug; /* bitmasks */
   size_t so_rcvbuf;
   unsigned int hash_table_size;
+  unsigned int hash_mask;
+  unsigned int hash_initval;
   int logger_nice_value;
   char empty_iface[32];
   char empty_prefix[32];
@@ -44,7 +46,7 @@ extern char *fname;
 
 #define FORCE_STAT_TIME 5
 
-#define VERSION "0.4.0"
+#define VERSION "0.4.2"
 
 /* config.c */
 struct config *read_config(char *fname);
