@@ -19,7 +19,7 @@
 
   Packet processing module
 
-  $Id: process.c,v 1.28 2004/04/06 08:49:35 bengen Exp $
+  $Id: process.c,v 1.29 2005/02/03 09:25:52 bengen Exp $
 */
 
 #include <sys/time.h>
@@ -354,7 +354,7 @@ void register_packet(struct iphdr *tmp_iphdr, size_t packet_length,
       p -> outdev = strdup(outdev_name);
       p -> prefix = strdup(prefix);
       p -> next = plist[ hash_val ];
-      p -> when = now;
+      p->since = p -> when = now;
       p -> local_uid = uid;
       p -> mac_len = mac_len;
       for (j=0;j<mac_len;j++)
@@ -469,6 +469,7 @@ int write_output_list(int fd, struct ipv4data *output_list)
   static char outdev[32];
   static char prefix[32];
 
+  static char timestring_since[128];
   static char timestring[128];
 
   struct tm timestructure;
@@ -511,18 +512,22 @@ int write_output_list(int fd, struct ipv4data *output_list)
     /* Time-as-string handling */
     if(ENABLED(OUT_TIMESTRING))
       {
+        localtime_r(&p->since, &timestructure);
+	strftime(timestring_since, sizeof(timestring_since),
+	         cfg->date_format, &timestructure);
+
 	localtime_r(&p->when, &timestructure);
 	strftime(timestring, sizeof(timestring), 
 		 cfg->date_format,&timestructure);
       }
     
-    len=snprintf(buf, 1023, cfg->acct_format, p->when, p->proto,
+    len=snprintf(buf, 1023, cfg->acct_format, p->since, p->when, p->proto,
 		 src, p->srcport, dst, p->dstport,
 		 p->count, p->bytes,
 		 indev, outdev,
 		 prefix,
 		 (int) p->local_uid,
-		 timestring,
+		 timestring_since, timestring,
 		 mac_str);
 
     if (write(fd,buf,len)==-1)
@@ -542,6 +547,7 @@ void write_list(void)
   char tmpn[255];
 
   while( (writepid = fork()) < 0) sleep(1);
+  /* FIXME: Check for fork() error */
   if (writepid!=0) return;
 
   /* Here goes the child */
